@@ -33,10 +33,10 @@ import sipconfig
 
 
 # Initialise the globals.
-pyqt_version = 0x040806
-pyqt_version_str = "4.8.6"
+pyqt_version = 0x040900
+pyqt_version_str = "4.9"
 
-sip_min_version = 0x040c02
+sip_min_version = 0x040d01
 
 qt_version = 0
 qt_edition = ""
@@ -66,8 +66,8 @@ dbuslibdirs = []
 dbuslibs = []
 
 
-# Under Windows qmake and the Qt DLLs must be into the system PATH otherwise
-# the dynamic linker won't be able to resolve the symbols.  On other systems we
+# Under Windows qmake and the Qt DLLs must be on the system PATH otherwise the
+# dynamic linker won't be able to resolve the symbols.  On other systems we
 # assume we can just run qmake by using its full pathname.
 if sys.platform == 'win32':
     MSG_CHECK_QMAKE = "Make sure you have a working Qt v4 qmake on your PATH."
@@ -175,7 +175,7 @@ def create_optparser():
             "comments of generated code [default: include timestamps]")
 
     if sys.platform != 'win32':
-        if sys.platform in ('linux2', 'darwin'):
+        if sys.platform in ('linux2', 'linux3', 'darwin'):
             pip_default = True
             pip_default_str = "enabled"
         else:
@@ -334,7 +334,8 @@ class ConfigurePyQt4:
             0x040700: "Qt_4_6_3",
             0x040701: "Qt_4_7_0",
             0x040702: "Qt_4_7_1",
-            0x050000: "Qt_4_7_2"
+            0x040800: "Qt_4_7_2",
+            0x050000: "Qt_4_8_0"
         }
 
     def check_modules(self):
@@ -359,6 +360,11 @@ class ConfigurePyQt4:
         check_module("QtMultimedia", "QAudioDeviceInfo",
                 "new QAudioDeviceInfo()")
         check_module("QtNetwork", "qhostaddress.h", "new QHostAddress()")
+
+        if sys.platform != 'win32':
+            check_module("QtDBus", "qdbusconnection.h",
+                    "QDBusConnection::systemBus()")
+
         check_module("QtDeclarative", "qdeclarativeview.h",
                 "new QDeclarativeView()")
         check_module("QtOpenGL", "qgl.h", "new QGLWidget()")
@@ -461,6 +467,19 @@ class ConfigurePyQt4:
         if "QtNetwork" in pyqt_modules:
             generate_code("QtNetwork")
 
+        if "QtDBus" in pyqt_modules:
+            qpy_inc_dir, qpy_lib_dir, qpy_lib = self._qpy_directories("QtDBus", "qpydbus")
+
+            if opts.bigqt:
+                cons_xtra_incdirs.append(qpy_inc_dir)
+                cons_xtra_libdirs.append(qpy_lib_dir)
+                cons_xtra_libs.append(qpy_lib)
+
+                generate_code("QtDBus")
+            else:
+                generate_code("QtDBus", extra_include_dirs=[qpy_inc_dir],
+                        extra_lib_dirs=[qpy_lib_dir], extra_libs=[qpy_lib])
+
         if "QtOpenGL" in pyqt_modules:
             generate_OpenGL_extras()
 
@@ -661,6 +680,9 @@ class ConfigurePyQt4:
         else:
             qpy_lib_dir = qpy_dir
 
+            if sys.platform == 'darwin' and opts.debug:
+                lib_name += '_debug'
+
         return os.path.join(src_dir, qpy_dir), os.path.abspath(qpy_lib_dir), lib_name
 
     def _static_plugins(self, mname):
@@ -744,6 +766,9 @@ class ConfigurePyQt4:
         if "QtGui" in pyqt_modules:
             qpylibs["QtGui"] = "qpygui.pro"
 
+        if "QtDBus" in pyqt_modules:
+            qpylibs["QtDBus"] = "qpydbus.pro"
+
         if "QtDeclarative" in pyqt_modules:
             qpylibs["QtDeclarative"] = "qpydeclarative.pro"
 
@@ -778,7 +803,7 @@ class ConfigurePyQt4:
                 f.write("QMAKE_MACOSX_DEPLOYMENT_TARGET = %s\n" % sipcfg.deployment_target)
 
             inc_path = [sipcfg.py_inc_dir]
-            if qpy in ("QtCore", "QtDeclarative", "QtOpenGL"):
+            if qpy in ("QtCore", "QtDBus", "QtDeclarative", "QtOpenGL"):
                 if sipcfg.sip_inc_dir != sipcfg.py_inc_dir:
                     inc_path.insert(0, sipcfg.sip_inc_dir)
 
@@ -1513,6 +1538,7 @@ def needed_qt_libs(mname, qt_libs):
     # as well as the libraries.
     LIB_DEPS = {
         "QtCore": [],
+        "QtDBus": ["QtCore"],
         "QtDeclarative": ["QtNetwork", "QtGui"],
         "QtGui": ["QtCore"],
         "QtHelp": ["QtGui"],
