@@ -1,7 +1,7 @@
 /*
  * This is the interface of the Qt Designer plugin.
  *
- * Copyright (c) 2010 Riverbank Computing Limited <info@riverbankcomputing.com>
+ * Copyright (c) 2011 Riverbank Computing Limited <info@riverbankcomputing.com>
  * 
  * This file is part of PyQt.
  * 
@@ -17,13 +17,8 @@
  * GPL Exception version 1.1, which can be found in the file
  * GPL_EXCEPTION.txt in this package.
  * 
- * Please review the following information to ensure GNU General
- * Public Licensing requirements will be met:
- * http://trolltech.com/products/qt/licenses/licensing/opensource/. If
- * you are unsure which license is appropriate for your use, please
- * review the following information:
- * http://trolltech.com/products/qt/licenses/licensing/licensingoverview
- * or contact the sales department at sales@riverbankcomputing.com.
+ * If you are unsure which license is appropriate for your use, please
+ * contact the sales department at sales@riverbankcomputing.com.
  * 
  * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
  * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -40,7 +35,9 @@
 #include <QObject>
 
 
+QT_BEGIN_NAMESPACE
 class QDesignerCustomWidgetInterface;
+QT_END_NAMESPACE
 
 
 class PyCustomWidgets
